@@ -1,9 +1,9 @@
-from zope.interface import implementer
-from six import iteritems
 from twisted.internet.defer import DeferredQueue, inlineCallbacks, maybeDeferred, returnValue
+from zope.interface import implementer
+
+from scrapyd.interfaces import IPoller
+from scrapyd.utils import get_spider_queues
 
-from .utils import get_spider_queues
-from .interfaces import IPoller
 
 @implementer(IPoller)
 class QueuePoller(object):
@@ -17,7 +17,7 @@ class QueuePoller(object):
     def poll(self):
         if not self.dq.waiting:
             return
-        for p, q in iteritems(self.queues):
+        for p, q in self.queues.items():
             c = yield maybeDeferred(q.count)
             if c:
                 msg = yield maybeDeferred(q.pop)
